@@ -19,6 +19,7 @@
  */
 
 #include <cstdlib>
+#include "plist.h"
 #include <plist/String.h>
 
 namespace PList
@@ -44,11 +45,30 @@ String& String::operator=(const PList::String& s)
     return *this;
 }
 
+String& String::operator=(const std::string& s)
+{
+    plist_free(_node);
+    _node = plist_new_string(s.c_str());
+    return *this;
+}
+
+String& String::operator=(const char* s)
+{
+    plist_free(_node);
+    _node = plist_new_string(s);
+    return *this;
+}
+
 String::String(const std::string& s) : Node(PLIST_STRING)
 {
     plist_set_string_val(_node, s.c_str());
 }
 
+String::String(const char *s) : Node(PLIST_STRING)
+{
+    plist_set_string_val(_node, s);
+}
+
 String::~String()
 {
 }
@@ -65,10 +85,8 @@ void String::SetValue(const std::string& s)
 
 std::string String::GetValue() const
 {
-    char* s = NULL;
-    plist_get_string_val(_node, &s);
+    const char* s = plist_get_string_ptr(_node, NULL);
     std::string ret = s ? s : "";
-    delete s;
     return ret;
 }
 
